@@ -23,7 +23,6 @@
 #include <unistd.h>
 #include <QDBusConnection>
 #include <QDir>
-#include <QRegExp>
 #include <QStandardPaths>
 #include <lomiri/transfers/system/logger.h>
 #include "apparmor.h"
@@ -151,7 +150,7 @@ AppArmor::getLocalPath(const QString& appId) {
             QStandardPaths::TempLocation);
     } else {
         QString dataPath = QStandardPaths::writableLocation(
-            QStandardPaths::DataLocation);
+            QStandardPaths::AppLocalDataLocation);
         QStringList pathComponents;
 
         if (!appId.isEmpty()) {
